@@ -176,7 +176,7 @@ gint glarea_motion_notify(GtkWidget *widget, GdkEventMotion *event)
   mesh_info *info = (mesh_info*)gtk_object_get_data(GTK_OBJECT(widget), "mesh_info");
 
   if (event->is_hint) {
-    // fix this!
+    /* fix this! */
 #if !defined(WIN32)
     gdk_window_get_pointer(event->window, &x, &y, &state);
 #endif
@@ -282,7 +282,7 @@ gint window_destroy(GtkWidget *widget)
 
 gint show_lwobject(char *lwobject_name)
 {
-  GtkWidget *window, *frame, *glarea;
+  GtkWidget *window, *glarea;
   mesh_info *info;
   lwObject *lwobject;
 
@@ -299,9 +299,6 @@ gint show_lwobject(char *lwobject_name)
   lw_object_scale(lwobject, 10.0 / lw_object_radius(lwobject));
 
 
-  /* create aspect frame */
-  frame = gtk_aspect_frame_new(NULL, 0.5,0.5, VIEW_ASPECT, FALSE);
-
   /* create new OpenGL widget */
   glarea = gtk_gl_area_new_vargs(NULL, /* no sharing */
 				 GDK_GL_RGBA,
@@ -361,10 +358,9 @@ gint show_lwobject(char *lwobject_name)
 
 
   /* put glarea into window and show it all */
-  gtk_container_add(GTK_CONTAINER(window), frame);
-  gtk_container_add(GTK_CONTAINER(frame),glarea);
+  gtk_container_add(GTK_CONTAINER(window), glarea);
+
   gtk_widget_show(glarea);
-  gtk_widget_show(frame);
   gtk_widget_show(window);
 
   return TRUE;
